Variable names are allowed to be verbose, and should be descriptive.

Code comments should only be added for complex logic or unintuitive code that is not adequately explained by the function names themselves.

Unit tests are not necessary. Tests should instead be written as simple examples demonstrating the functionality of relevant functions.

Always use 4 spaces for indentation when writing code.
